@@ -26,7 +26,7 @@ def add_auth(
         user_schema_read=schema_read,
         user_schema_create=schema_create,
         user_schema_update=schema_update,
-        auth_prefix="/_db" + auth_prefix,
+        auth_prefix="/_sql" + auth_prefix,
     )
 
     app.include_router(auth_router, prefix=auth_prefix, tags=["auth"])
@@ -50,6 +50,6 @@ def add_auth(
                 auth_backend=auth_backend,
                 providers=providers,
                 post_login_redirect=post_login_redirect,
-                prefix="/_db" + oauth_prefix,
+                prefix="/_sql" + oauth_prefix,
             )
         )
